@@ -1,11 +1,11 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 2.0.6
+|  |  |__   |  |  | | | |  version 2.1.1
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
-Copyright (c) 2013-2016 Niels Lohmann <http://nlohmann.me>.
+Copyright (c) 2013-2017 Niels Lohmann <http://nlohmann.me>.
 
 Permission is hereby  granted, free of charge, to any  person obtaining a copy
 of this software and associated  documentation files (the "Software"), to deal
@@ -160,12 +160,30 @@ TEST_CASE("value conversion")
         {
             std::forward_list<json> a = j.get<std::forward_list<json>>();
             CHECK(json(a) == j);
+
+            CHECK_THROWS_AS(json(json::value_t::null).get<std::forward_list<json>>(), std::logic_error);
+            CHECK_THROWS_WITH(json(json::value_t::null).get<std::forward_list<json>>(),
+                              "type must be array, but is null");
         }
 
         SECTION("std::vector<json>")
         {
             std::vector<json> a = j.get<std::vector<json>>();
             CHECK(json(a) == j);
+
+            CHECK_THROWS_AS(json(json::value_t::null).get<std::vector<json>>(), std::logic_error);
+            CHECK_THROWS_WITH(json(json::value_t::null).get<std::vector<json>>(),
+                              "type must be array, but is null");
+
+#if not defined(JSON_NOEXCEPTION)
+            SECTION("reserve is called on containers that supports it")
+            {
+                // making the call to from_json throw in order to check capacity
+                std::vector<float> v;
+                CHECK_THROWS_AS(nlohmann::from_json(j, v), std::logic_error);
+                CHECK(v.capacity() == j.size());
+            }
+#endif
         }
 
         SECTION("std::deque<json>")
@@ -184,6 +202,8 @@ TEST_CASE("value conversion")
             CHECK_THROWS_AS(json(json::value_t::number_unsigned).get<json::array_t>(), std::logic_error);
             CHECK_THROWS_AS(json(json::value_t::number_float).get<json::array_t>(), std::logic_error);
 
+            CHECK_THROWS_WITH(json(json::value_t::object).get<std::vector<int>>(),
+                              "type must be array, but is object");
             CHECK_THROWS_WITH(json(json::value_t::null).get<json::array_t>(),
                               "type must be array, but is null");
             CHECK_THROWS_WITH(json(json::value_t::object).get<json::array_t>(),
@@ -952,14 +972,14 @@ TEST_CASE("value conversion")
                 auto m5 = j5.get<std::list<std::string>>();
             }
 
-            //SECTION("std::forward_list")
-            //{
-            //    auto m1 = j1.get<std::forward_list<int>>();
-            //    auto m2 = j2.get<std::forward_list<unsigned int>>();
-            //    auto m3 = j3.get<std::forward_list<double>>();
-            //    auto m4 = j4.get<std::forward_list<bool>>();
-            //    auto m5 = j5.get<std::forward_list<std::string>>();
-            //}
+            SECTION("std::forward_list")
+            {
+                auto m1 = j1.get<std::forward_list<int>>();
+                auto m2 = j2.get<std::forward_list<unsigned int>>();
+                auto m3 = j3.get<std::forward_list<double>>();
+                auto m4 = j4.get<std::forward_list<bool>>();
+                auto m5 = j5.get<std::forward_list<std::string>>();
+            }
 
             SECTION("std::vector")
             {
@@ -1004,6 +1024,8 @@ TEST_CASE("value conversion")
                 CHECK_THROWS_AS((json().get<std::vector<json>>()), std::logic_error);
                 CHECK_THROWS_AS((json().get<std::list<json>>()), std::logic_error);
 
+                // does type really must be an array? or it rather must not be null?
+                // that's what I thought when other test like this one broke
                 CHECK_THROWS_WITH((json().get<std::list<int>>()), "type must be array, but is null");
                 CHECK_THROWS_WITH((json().get<std::vector<int>>()), "type must be array, but is null");
                 CHECK_THROWS_WITH((json().get<std::vector<json>>()), "type must be array, but is null");
