@@ -1,11 +1,11 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 2.0.6
+|  |  |__   |  |  | | | |  version 2.1.1
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
-Copyright (c) 2013-2016 Niels Lohmann <http://nlohmann.me>.
+Copyright (c) 2013-2017 Niels Lohmann <http://nlohmann.me>.
 
 Permission is hereby  granted, free of charge, to any  person obtaining a copy
 of this software and associated  documentation files (the "Software"), to deal
@@ -250,17 +250,31 @@ TEST_CASE("object inspection")
             ss.str(std::string());
 
             // use stringstream for JSON serialization
-            json j_number = 3.141592653589793;
+            json j_number = 3.14159265358979;
             ss << j_number;
 
             // check that precision has been overridden during serialization
-            CHECK(ss.str() == "3.141592653589793");
+            CHECK(ss.str() == "3.14159265358979");
 
             // check that precision has been restored
             CHECK(ss.precision() == 3);
         }
     }
 
+    SECTION("round trips")
+    {
+        for (const auto& s :
+    {"3.141592653589793", "1000000000000000010E5"
+    })
+        {
+            json j1 = json::parse(s);
+            std::string s1 = j1.dump();
+            json j2 = json::parse(s1);
+            std::string s2 = j2.dump();
+            CHECK(s1 == s2);
+        }
+    }
+
     SECTION("return the type of the object (explicit)")
     {
         SECTION("null")
